@@ -1,23 +1,28 @@
 # Import functions
-import os
-import torch
-import numpy as np
 import copy
-import pandas as pd 
-
-from torch.utils.data import DataLoader
-
-import umap.umap_ as umap
+import itertools
+import os
 import random
-import itertools 
+import logging
+from pathlib import Path
+
+import numpy as np
+import pandas as pd
+import torch
+import umap.umap_ as umap
+from torch.utils.data import DataLoader
 
 from move.models import vae
 from move.utils import dataloaders
-from move.utils.model_utils import get_latent, cal_recon, cal_cat_recon, cal_con_recon, get_baseline, change_drug, cal_sig_hits, correction_new, get_start_end_positions 
 from move.utils.data_utils import initiate_default_dicts
+from move.utils.model_utils import (cal_cat_recon, cal_con_recon, cal_recon,
+                                    cal_sig_hits, change_drug, get_baseline,
+                                    get_latent, get_start_end_positions)
 from move.utils.seed import set_global_seed
 
 
+logger = logging.getLogger('train')
+
 def optimize_reconstruction(nHiddens, nLatents, nLayers, nDropout, nBeta, batch_sizes, nepochs, repeat, lrate, kldsteps, batchsteps, patience, cuda, processed_data_path, cat_list, con_list, continuous_weights, categorical_weights, seed):
     """
     Performs hyperparameter tuning for the reconstruction
@@ -87,20 +92,22 @@ def optimize_reconstruction(nHiddens, nLatents, nLayers, nDropout, nBeta, batch_
 
     results_df = []
     
-    print('Beginning the hyperparameter tuning for reconstruction.\n')
+    logger.info('Beginning the hyperparameter tuning for reconstruction.\n')
     iters = itertools.product(nHiddens, nLatents, nLayers, nDropout, nBeta, batch_sizes, range(repeat))
     for nHidden, nLatent, nl, drop, b, batch_size, r in iters:
+
         combi = str([nHidden] * nl) + "+" + str(nLatent) + ", drop: " + str(drop) +", b: " + str(b) + ", batch: " + str(batch_size)
-
-        best_model, loss, ce, sse, KLD, train_loader, _, kld_w, cat_shapes, con_shapes, best_epoch = train_model(cat_list_train, con_list_train, categorical_weights, continuous_weights, batch_size, nHidden, nl, nLatent, b, drop, cuda, kldsteps, batchsteps, nepochs, lrate, seed+r, test_loader, patience, early_stopping=True)   
-
-
+        
+        logging.info(f'Testing: {combi}')
+        
+        best_model, loss, ce, sse, KLD, train_loader, _, kld_w, cat_shapes, con_shapes, best_epoch = train_model(cat_list_train, con_list_train, categorical_weights, continuous_weights, batch_size, nHidden, nl, nLatent, b, drop, cuda, kldsteps, batchsteps, nepochs, lrate, seed+r, test_loader, patience, early_stopping=True)
+        
         # get results
         latent, latent_var, cat_recon, con_recon, cat_class, loss, likelihood, latent_test, latent_var_test, cat_recon_test, cat_class_test, con_recon_test, loss_test, likelihood_test = get_latent(best_model, train_loader, test_loader, kld_w)
-
+        
         # Calculate reconstruction accuracy
         cat_true_recon, con_true_recon, cat_true_recon_test, con_true_recon_test = cal_recon(cat_shapes, cat_recon, cat_class, train_loader, con_recon, con_shapes, cat_recon_test, cat_class_test, test_loader, con_recon_test)
-
+        
         # Save output
         recon_acc[combi].append(cat_true_recon + con_true_recon)
         latents[combi].append(latent)
@@ -109,7 +116,7 @@ def optimize_reconstruction(nHiddens, nLatents, nLayers, nDropout, nBeta, batch_
         loss_train[combi].append(loss)
         likelihoods[combi].append(likelihood)
         best_epochs[combi].append(best_epoch)
-
+        
         recon_acc_tests[combi].append(cat_true_recon_test + con_true_recon_test)
         latents_tests[combi].append(latent_test)
         con_recons_tests[combi].append(con_recon_test)
@@ -139,10 +146,10 @@ def optimize_reconstruction(nHiddens, nLatents, nLayers, nDropout, nBeta, batch_
             'loss_test': np.array(loss_test),
             'likelihood_test': np.array(likelihood_test.cpu())
         })
-        
+    
     results_df = pd.DataFrame(results_df)
     
-    print('\nFinished the hyperparameter tuning for reconstruction. Saving the results.')
+    logger.info('Finished the hyperparameter tuning for reconstruction. Saving the results.')
     
     # Save output
     np.save(processed_data_path + "hyperparameters/latent_benchmark_final.npy", latents)
@@ -152,7 +159,7 @@ def optimize_reconstruction(nHiddens, nLatents, nLayers, nDropout, nBeta, batch_
     np.save(processed_data_path + "hyperparameters/loss_benchmark_final.npy", loss_train)
     np.save(processed_data_path + "hyperparameters/likelihood_benchmark_final.npy", likelihoods)
     np.save(processed_data_path + "hyperparameters/best_epochs_benchmark_final.npy", best_epochs)
-
+    
     np.save(processed_data_path + "hyperparameters/test_latent_benchmark_final.npy", latents_tests)
     np.save(processed_data_path + "hyperparameters/test_con_recon_benchmark_final.npy", con_recons_tests)
     np.save(processed_data_path + "hyperparameters/test_cat_recon_benchmark_final.npy", cat_recons_tests)
@@ -160,12 +167,13 @@ def optimize_reconstruction(nHiddens, nLatents, nLayers, nDropout, nBeta, batch_
     np.save(processed_data_path + "hyperparameters/test_loss_benchmark_final.npy", loss_tests)
     np.save(processed_data_path + "hyperparameters/test_likelihood_benchmark_final.npy", likelihood_tests)
     
-    print('The results saved.\n')
+    # print tsv
+    results_df.to_csv(processed_data_path + "hyperparameters/hyperparameters.results.tsv", sep="\t")
+    logger.info('The results saved.\n')
     
     return(likelihood_tests, recon_acc_tests, recon_acc, results_df)
 
-    
-    
+
 def optimize_stability(nHiddens, nLatents, nDropout, nBeta, repeat, nepochs, nLayers, batch_sizes, lrate, kldsteps, batchsteps, cuda, path, con_list, cat_list, continuous_weights, categorical_weights, seed):
     
     """
@@ -200,11 +208,11 @@ def optimize_stability(nHiddens, nLatents, nDropout, nBeta, repeat, nepochs, nLa
     
     models, latents, embeddings, con_recons, cat_recons, recon_acc, los, likelihood = initiate_default_dicts(1, 7)
     
-    print('Beginning the hyperparameter tuning for stability.\n')
+    logger.info('Beginning the hyperparameter tuning for stability.')
     iters = itertools.product(nHiddens, nLatents, nLayers, nDropout, nBeta, range(repeat))
     for nHidden, nLatent, nl, drop, b, r in iters:
         combi = str([nHidden] * nl) + "+" + str(nLatent) + ", do: " + str(drop) +", b: " + str(b)
-        print(combi)
+        logger.info(combi)
 
         best_model, loss, ce, sse, KLD, train_loader, _, kld_w, cat_shapes, con_shapes, best_epoch = train_model(cat_list, con_list, categorical_weights, continuous_weights, batch_sizes, nHidden, nl, nLatent, b, drop, cuda, kldsteps, batchsteps, nepochs, lrate, seed+r, test_loader=None, patience=None, early_stopping=False)
 
@@ -229,10 +237,9 @@ def optimize_stability(nHiddens, nLatents, nDropout, nBeta, repeat, nepochs, nLa
         embeddings[combi].append(embedding)
         con_recons[combi].append(con_recon)
         cat_recons[combi].append(cat_recon)
-        
-
+    
     # Saving the results
-    print('\nFinished the hyperparameter tuning for stability. Saving the results.')
+    logger.info('\nFinished the hyperparameter tuning for stability. Saving the results.')
     
     np.save(path + "hyperparameters/embedding_stab.npy", embeddings)
     np.save(path + "hyperparameters/latent_stab.npy", latents)
@@ -240,7 +247,7 @@ def optimize_stability(nHiddens, nLatents, nDropout, nBeta, repeat, nepochs, nLa
     np.save(path + "hyperparameters/cat_recon_stab.npy", cat_recons)
     np.save(path + "hyperparameters/recon_acc_stab.npy", recon_acc)
     
-    print('The results saved.\n')
+    logger.info('The results saved.\n')
     
     return(embeddings, latents, con_recons, cat_recons, recon_acc)
 
@@ -274,72 +281,50 @@ def train_model_association(path, cuda, nepochs, nLatents, batch_sizes, nHidden,
         categorical_names: list of strings of categorical data names
         data_of_interest: str of data type name whose features are changed to test their effects
         seed: int of seed number  
-    """ 
-
-    results, recon_results, recon_results_1, mean_bas = initiate_default_dicts(n_empty_dicts=0, n_list_dicts=4)
+    """
+        
+    # For data saving results
+    output_path = Path(path) / "05_identify_associations"
+    (output_path / "sig_overlap").mkdir(parents=True, exist_ok=True)
 
     start, end = get_start_end_positions(cat_list, categorical_names, data_of_interest)
-
     iters = itertools.product(nLatents, range(repeats))
-
+    
+    logger.info('Beginning training the model.\n')
     # Running the framework    
-    for nLatent, repeat in iters: 
+    for nLatent, repeat in iters:
+        logger.info('Training model with latent %i and repeat %i' % (nLatent, repeat))
         best_model, loss, ce, sse, KLD, train_loader, _, kld_w, cat_shapes, con_shapes, best_epoch = train_model(cat_list, con_list, categorical_weights, continuous_weights, batch_sizes, nHidden, nl, nLatent, nBeta, drop, cuda, kldsteps, batchsteps, nepochs, lrate, seed+repeat, test_loader=None, patience=None, early_stopping=False)
-
-
+        
         train_test_loader = DataLoader(dataset=train_loader.dataset, batch_size=train_loader.batch_size, drop_last=False,
                               shuffle=False, pin_memory=train_loader.pin_memory)
-
+        
         latent, latent_var, cat_recon, cat_class, con_recon, loss, likelihood = best_model.latent(train_test_loader, kld_w)
-
+        
         con_recon = np.array(con_recon)
         con_recon = torch.from_numpy(con_recon)
-
+        
         mean_baseline = get_baseline(best_model, train_test_loader, con_recon, repeat=10, kld_w=kld_w)
         recon_diff, groups = change_drug(best_model, train_test_loader, con_recon, drug, start, end, kld_w)
         stat = cal_sig_hits(recon_diff, groups, drug, mean_baseline, train_loader.dataset.con_all)
-
-        results[nLatent].append(stat)
+        
         recon_diff_corr = dict()
         for r_diff in recon_diff.keys():
             recon_diff_corr[r_diff] = recon_diff[r_diff] - np.abs(mean_baseline[groups[r_diff]])
-
-        mean_bas[nLatent].append(mean_baseline)
-        recon_results[nLatent].append(recon_diff_corr)
-        recon_results_1[nLatent].append(recon_diff)
-
-
-    # Saving results
-    isExist = os.path.exists(path + 'wp2.2/sig_overlap/')
-    if not isExist:
-        os.makedirs(path + 'wp2.2/sig_overlap/')
-
-    isExist = os.path.exists(path + 'results/')
-    if not isExist:
-        os.makedirs(path + 'results/')
-
-    with open(path + "results/results_" + version + ".npy", 'wb') as f:
-        np.save(f, results)
-    with open(path + "results/results_recon_" + version + ".npy", 'wb') as f:
-        np.save(f, recon_results)
-    with open(path + "results/results_groups_" + version + ".npy", 'wb') as f:
-        np.save(f, groups)
-    with open(path + "results/results_recon_mean_baseline_" + version + ".npy", 'wb') as f:
-        np.save(f, mean_bas)
-    with open(path + "results/results_recon_no_corr_" + version + ".npy", 'wb') as f:
-        np.save(f, recon_results_1)
-
-    cor_results = correction_new(results)
-
-    with open(path + "wp2.2/sig_overlap/cor_results_" + version + ".npy", 'wb') as f:
-        np.save(f, cor_results)
         
-    
+        # Saving the files 
+        np.save(output_path / f'results_{nLatent}_{repeat}_{version}', stat)
+        np.save(output_path / f'recon_results_{nLatent}_{repeat}_{version}', np.array(list(recon_diff_corr.values())))
+        np.save(output_path / f'mean_bas_{nLatent}_{repeat}_{version}', mean_baseline)
+        np.save(output_path / f'recon_results_1_{nLatent}_{repeat}_{version}', np.array(list(recon_diff.values())))
+   
+    np.save(output_path / f"results_groups_{version}.npy", np.array(list(groups.values())))
+    logger.info('\nFinished training the model.')
     
 def train_model(cat_list, con_list, categorical_weights, continuous_weights, batch_size, nHidden, nl, nLatent, b, drop, cuda, kldsteps, batchsteps, nepochs, lrate, seed, test_loader, patience, early_stopping):
     """
     Performs hyperparameter tuning for stability
-   
+    
     inputs:
         cat_list: list with input data of categorical data type
         con_list: list with input data of continuous data type  
@@ -376,12 +361,12 @@ def train_model(cat_list, con_list, categorical_weights, continuous_weights, bat
     
     if seed is not None:
         set_global_seed(seed)
-
+    
     # Initiate loader
     mask, train_loader = dataloaders.make_dataloader(cat_list=cat_list, 
                                                      con_list=con_list, 
                                                      batchsize=batch_size)
-
+    
     con_shapes = train_loader.dataset.con_shapes
     cat_shapes = train_loader.dataset.cat_shapes
     
@@ -394,60 +379,55 @@ def train_model(cat_list, con_list, categorical_weights, continuous_weights, bat
                     categorical_weights=categorical_weights, 
                     dropout=drop, 
                     cuda=cuda).to(device)      
-
+    
     # Create lists for saving loss
     loss = list();ce = list();sse = list();KLD = list();loss_test = list()
-
-
+    
     l = len(kldsteps)
     rate = 20/l 
     kld_w = 0
     update = 1 + rate
     l_min = float('inf')
     count = 0
-
+    
     # Train model
     for epoch in range(1, nepochs + 1):
         if epoch in kldsteps:
             kld_w = 1/20 * update
             update += rate
-
+        
         if epoch in batchsteps:
             train_loader = DataLoader(dataset=train_loader.dataset,batch_size=int(train_loader.batch_size * 1.5),shuffle=True,drop_last=True)
-
+        
         l, c, s, k = model.encoding(train_loader, epoch, lrate, kld_w)
-
-
+        
         loss.append(l)
         ce.append(c)
         sse.append(s)
         KLD.append(k)
-
+        
         if early_stopping:
-
             out = model.latent(test_loader, kld_w)
             loss_test.append(out[-2])
-            print("Likelihood: " + str(out[-1]))
-
-
+            logger.info("Likelihood: " + str(out[-1]))
+            
             if out[-1] > l_min and count < patience: 
                 count+=1
                 
                 if count % 5 == 0:
                     lrate = lrate - lrate*0.10
-
-
+            
             elif count == patience:
                 break
-
+            
             else:
                 l_min = out[-1]
                 best_model = copy.deepcopy(model)
                 best_epoch = epoch
                 count = 0
- 
+        
         else:
             best_model = copy.deepcopy(model)
             best_epoch = None
-
-    return(best_model, loss, ce, sse, KLD, train_loader, mask, kld_w, cat_shapes, con_shapes, best_epoch)        
\ No newline at end of file
+    
+    return(best_model, loss, ce, sse, KLD, train_loader, mask, kld_w, cat_shapes, con_shapes, best_epoch)        
